@@ -438,7 +438,7 @@ BBDB sets the default of that option."
 	  (insert
 	   (mapconcat
 	    (lambda (r)
-	      (format "%S, error: %S" (car r) (cadr r)))
+	      (format "%S\nerror: %S" (car r) (cadr r)))
 	    duds "\n\n"))
 	  (fit-window-to-buffer)
 	  (goto-char (point-min)))
@@ -474,7 +474,9 @@ BBDB sets the default of that option."
 		    ebdb-default-name-class
 		    :surname l-name
 		    :given-names (when f-name (split-string f-name " " nil))
-		    :affix affix)
+		    :affix (if (stringp affix)
+			       affix
+			     (mapconcat #'identity affix " ")))
 		 (make-instance 'ebdb-field-name-simple
 				:name (if f-name
 					  (concat f-name " " l-name)
